/*
   math/matrix4f.cc
   This file is part of the Osirion project and is distributed under
   the terms of the GNU General Public License version 2
*/

#include <string.h>

#include <cmath>

#include "math/matrix4f.h"

namespace math
{

Matrix4f::Matrix4f()
{
	clear();
}

Matrix4f::Matrix4f(const Matrix4f & other)
{
	assign(other);
}

Matrix4f::Matrix4f(const Axis & axis)
{
	assign(axis);
}

void Matrix4f::clear()
{
	memset(matrix, 0, sizeof(matrix));
}

void Matrix4f::unity()
{
	memset(matrix, 0, sizeof(matrix));
	for (int i=0; i <4; i++)
		matrix[i][i] = 1;
}

void Matrix4f::assign(const Matrix4f & other)
{
	memcpy(matrix, other.matrix, sizeof(matrix));
}

void Matrix4f::assign(const Axis & axis)
{
	memset(matrix, 0, sizeof(matrix));
	for (int i=0; i < 3; i++) {
		memcpy(&matrix[i][0], axis[i].ptr(), sizeof(float) * 3);
	}
	matrix[3][3] = 1;
}

Matrix4f & Matrix4f::operator=(const Matrix4f &other)
{
	assign(other);
	return(*this);
}

Matrix4f & Matrix4f::operator=(const Axis & axis)
{
	assign(axis);
	return(*this);
}

Matrix4f const Matrix4f::transpose()
{
	Matrix4f t;
	
	for (size_t i = 0; i < 4; i++)
		for (size_t j = 0; j < 4; j++)
			t.matrix[j][i] = matrix[i][j];
	return t;
}

}
