/*
   sys/sys.h
   This file is part of the Osirion project and is distributed under
   the terms of the GNU General Public License version 2
*/

#ifndef __INCLUDED_SYS_H__
#define __INCLUDED_SYS_H__

#include "config.h"

#include <string>

/// maximum line size throught the game
#define MAXCMDSIZE 1024

/// contains operating system dependent functions
/** sys is a core subsystem
 */
namespace sys
{
typedef void(* signalfunc)(int signum);

/// returns true if a path exists and it is a directory
bool directory_exists(const std::string &path);

/// returns true if a file exists
bool file_exists(const std::string &filename);

/// create a directory
void mkdir(const std::string &path);

/// intercept OS signals
void signal(int signum, signalfunc handler);

/**
 * @brief operation system exit() application
 * @param status return value
 */
void quit(int status);

/// suspend process for a number of seconds
void sleep(float seconds);

/// return the current system time of day, in seconds after midnight
unsigned long time();

/// get the current system date and time
void get_datetime(int &year, int & month, int & day, int & hours, int & minutes);
}

#include "sys/consoleinterface.h"

#endif // __INCLUDED_SYS_H__

